Coverage for /run/media/veganeco/water/status600.com/pypi/reptilian_climates/modules_series_2/ships/fields/gardens_pip/rich/errors.py: 100%

1 class ConsoleError(Exception):

2 """An error in console operation."""

3

4

5 class StyleError(Exception):

6 """An error in styles."""

7

8

9 class StyleSyntaxError(ConsoleError):

10 """Style was badly formatted."""

11

12

13 class MissingStyle(StyleError):

14 """No such style."""

15

16

17 class StyleStackError(ConsoleError):

18 """Style stack is invalid."""

19

20

21 class NotRenderableError(ConsoleError):

22 """Object is not renderable."""

23

24

25 class MarkupError(ConsoleError):

26 """Markup was badly formatted."""

27

28

29 class LiveError(ConsoleError):

30 """Error related to Live display."""

31

32

33 class NoAltScreen(ConsoleError):

34 """Alt screen mode was required."""